/**
 * Getting Started with Capture.
 * 
 * Reading and displaying an image from an attached Capture device. 
 */

import processing.video.*;

Capture Lcam;
Capture Rcam;

void setup() {
  size(1280, 480);

  String[] cameras = Capture.list();

  if (cameras == null) {
    println("Failed to retrieve the list of available cameras, will try the default...");
    Lcam = new Capture(this, 640, 480);
    Rcam = new Capture(this, 640, 480);
  } 
  if (cameras.length == 0) {
    println("There are no cameras available for capture.");
    exit();
  } else {
    println("Available cameras:");
    for (int i = 0; i < cameras.length; i++) {
      println(cameras[i]);
    }

    // The camera can be initialized directly using an element
    // from the array returned by list():
    //cam = new Capture(this, cameras[0]);
    // Or, the settings can be defined based on the text in the list
    Lcam = new Capture(this, 640, 480, "/dev/video1", 24);
    Rcam = new Capture(this, 640, 480, "/dev/video0", 24);

    // Start capturing the images from the camera
    Lcam.start();
    Rcam.start();
  }
}

void draw() {
  if (Lcam.available() == true) {
    Lcam.read();
  }  
  if (Rcam.available() == true) {
    Rcam.read();
  }
  image(Lcam, 0, 0);
  image(Rcam, 640, 0);// The following does the same as the above image() line, but 
  // is faster when just drawing the image without any additional 
  // resizing, transformations, or tint.
  //set(0, 0, cam);
}

